# frozen_string_literal: true

InstantMessage.prepend(Turbo::Broadcastable)
InstantMessage.class_eval do
  field :is_initial, type: Mongoid::Boolean, default: false
  field :automation_ids, type: Array, default: []

  after_create :broadcast_append_to_channel, :update_waiting_for_bot

  def update_waiting_for_bot
    channel.update(waiting_for_bot: false)
  end

  def broadcast_append_to_channel
    if type == 'm'
      # Broadcast du message normal et nettoyage du message système
      broadcast_append_to_messages
      broadcast_system_message_clear
    else
      # Broadcast du message système
      broadcast_replace_system_message
    end
  end

  def user?
    !assistant?
  end

  def assistant?
    user.is_a?(Bot)
  end

  private

  def broadcast_append_to_messages
    broadcast_append_to "channels_messages_#{channel.id}",
                        target: "channels_messages_#{channel.id}",
                        renderable: InstantMessages::ItemComponent.new(self)
  end

  def broadcast_system_message_clear
    broadcast_update_to "system_message_#{channel.id}",
                        target: "system_message_#{channel.id}",
                        html: ''
  end

  def broadcast_replace_system_message
    broadcast_update_to "system_message_#{channel.id}",
                        target: "system_message_#{channel.id}",
                        renderable: InstantMessages::SystemMessageComponent.new(self)
  end

  def suppressed_turbo_broadcasts?
    false
  end
end
